@@ -28,6 +28,7 @@
 #include "unity_screen_service.h"
 #include "unity_input_service.h"
 #include "dbus_connection_thread.h"
+#include "dbus_event_loop.h"
 #include "display_configuration_policy.h"
 #include "steady_clock.h"
 
@@ -241,7 +242,7 @@ std::shared_ptr<usc::InputConfiguration> usc::Server::the_input_configuration()
     return input_configuration(
         [this]
         {
-            return std::make_shared<MirInputConfiguration>();
+            return std::make_shared<MirInputConfiguration>(the_input_device_hub());
         });
 }
 
@@ -292,12 +293,22 @@ std::shared_ptr<usc::ScreenHardware> usc::Server::the_screen_hardware()
         });
 }
 
+std::shared_ptr<usc::DBusEventLoop> usc::Server::the_dbus_event_loop()
+{
+    return dbus_loop(
+        [this]
+        {
+            return std::make_shared<DBusEventLoop>();
+        });
+
+}
+
 std::shared_ptr<usc::DBusConnectionThread> usc::Server::the_dbus_connection_thread()
 {
     return dbus_thread(
         [this]
         {
-            return std::make_shared<DBusConnectionThread>(dbus_bus_address());
+            return std::make_shared<DBusConnectionThread>(the_dbus_event_loop());
         });
 }
 
@@ -307,7 +318,8 @@ std::shared_ptr<usc::UnityScreenService> usc::Server::the_unity_screen_service()
         [this]
         {
             return std::make_shared<UnityScreenService>(
-                    the_dbus_connection_thread(),
+                    the_dbus_event_loop(),
+                    dbus_bus_address(),
                     the_screen());
         });
 }
@@ -318,7 +330,8 @@ std::shared_ptr<usc::UnityInputService> usc::Server::the_unity_input_service()
         [this]
         {
             return std::make_shared<UnityInputService>(
-                    the_dbus_connection_thread(),
+                    the_dbus_event_loop(),
+                    dbus_bus_address(),
                     the_input_configuration());
         });
 }
